@@ -1533,7 +1533,8 @@ If update process is interrupted, return nil.")
 	(flag-table (elmo-flag-table-load (elmo-folder-msgdb-path folder)))
 	(before-append t))
     (when ignore-msgdb
-      (elmo-msgdb-flag-table (elmo-folder-msgdb folder) flag-table)
+      (ignore-errors
+	(elmo-msgdb-flag-table (elmo-folder-msgdb folder) flag-table))
       (elmo-folder-clear folder (not disable-killed)))
     (unless no-check (elmo-folder-check folder))
     (condition-case nil
